version 1.0.6
=============

 * s5p_plot.py [draw_qhist]: added grid-lines and denisty parameter, improved axis labels
 * Rearranged source tree to comply with PIP 517, 518 (requires: setuptools 42 or later)
 * Renamed lib.sw_version.py to version.py
 * Removed all test-modules and examples because these are obsolete. Will be replaced by up-to-date code in future commits
 * Fixed pylint warnings
 * Updated Copyright line in all modules
 * Updated files INSTALL and README
 * Added ToDo, which contains a listing of new functionality to be implemented before a new minor release
 * Added ChangeLog
